==> gtk-acl-0.1.0.tar.gz: gtk-acl-0.1.0/src/main.c <==
/* Created by Anjuta version 1.0.0 */
/*	This file will not be overwritten */
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 



#include <stdio.h>
#include <locale.h>

#include "config.h"
#include "gtk/gtk.h"


#include "gtkacl.h"

int main(gint argc, gchar **argv)
{
	GtkWidget *win_main;
	GtkWidget *win_acl;
	GtkWidget *vbox_main;
	GList     *list_child;
	
	gtk_init(&argc, &argv);
	
	setlocale (LC_ALL, "");
	bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
	textdomain (PACKAGE);
	
	if (argc < 2) {
		g_print(_("Usage : gtk_acl <filename>\n"));
		exit(0);
	}		
	
	if (g_strcasecmp(argv[1], "--version") == 0)
	{
		g_print("%s version %s\n", PACKAGE, VERSION);
		exit(0);
	}
	
	
	win_main = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_widget_show(win_main);
	
	win_acl = gtk_acl_new();
	gtk_container_add(GTK_CONTAINER(win_main), win_acl);
	gtk_widget_show_all(win_acl);
	
	
	gtk_acl_load_file(GTK_ACL(win_acl), argv[1]);
	
	gtk_main();
	
	return (0);
}

==> gtk-acl-0.1.1.tar.gz: gtk-acl-0.1.1/src/main.c <==
/* Created by Anjuta version 1.0.0 */
/*	This file will not be overwritten */
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include <stdio.h>
#include <locale.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>

#include "config.h"
#include "gtk/gtk.h"

#include "gtkacl.h"


//#include "bonobo_gtkacl.h"


void on_destroy(GtkWidget widget, gpointer data);


//
int main(gint argc, gchar **argv)
{
	GtkWidget *win_main;
	GtkWidget *win_acl;
	GtkWidget *vbox_main;
	GList     *list_child;
	
	gtk_init(&argc, &argv);
	
	setlocale (LC_ALL, "");
	bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
	textdomain (PACKAGE);
	
	/***** Check parameters *****/
	
	if (argc < 2) 
	{
		g_print(_("Usage : gtk-acl <filename>\n"));
		exit(0);
	}		
	
	if (g_strcasecmp(argv[1], "--version") == 0)
	{
		g_print("%s version %s\n", PACKAGE, VERSION);
		exit(0);
	}

	/*int fd;
	fd = open(argv[1], O_RDONLY);
	if (fd == -1)
	{
		close(fd);
		g_print("Wrong path!\n");
		return 1;
	}
	close(fd);*/
	
	struct stat s_stat;
		
	if (stat(argv[1], &s_stat) == -1)
	{
		g_print(_("Wrong path!\n"));
		return 1;
	}
	
	/*create_bonobo_container(argc, argv);
	exit(0);*/
	
	/***** *****/
	
	win_main = gtk_window_new(GTK_WINDOW_TOPLEVEL);
	gtk_window_set_title(GTK_WINDOW(win_main), _("ACL Management"));
	g_signal_connect(win_main, "destroy", on_destroy, NULL);
	gtk_widget_show(win_main);
	
	win_acl = gtk_acl_new();
	gtk_acl_set_advanced_mode(GTK_ACL(win_acl), FALSE);
	gtk_container_add(GTK_CONTAINER(win_main), win_acl);
	gtk_widget_show(win_acl);
	
	
	gtk_acl_load_file(GTK_ACL(win_acl), argv[1], TYPE_ACCESS);
	//gtk_acl_load_file(GTK_ACL(win_acl), argv[1], TYPE_DEFAULT);
	
	gtk_main();
	
	return (0);
}



//
void on_destroy(GtkWidget widget, gpointer data)
{
	gtk_main_quit();
}
